@@ -101,6 +101,7 @@ except ImportError as error:
     to_rphiz = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -490,6 +491,15 @@ class VectorField(FrozenClass):
         """setter of components"""
         if type(value) is dict:
             for key, obj in value.items():
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[key] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "SciDataTool.Classes", obj.get("__class__"), "components"
