@@ -54,6 +54,7 @@ def plot_2D(
     scale=None,
     width=0.005,
     symbol=".",
+    is_indlabels=False,
 ):
     """Plots a 2D graph (curve, bargraph or barchart) comparing fields in Ydatas
 
@@ -195,7 +196,15 @@ def plot_2D(
             ax.xaxis.set_ticks(xticks)
             plt.xticks(rotation=90, ha="center", va="top")
         if xticklabels is not None:
-            ax.set_xticklabels(xticklabels, rotation=90)
+            if is_indlabels:
+                ax.set_xticklabels(
+                    [i + 1 for i in range(len(xticklabels))], rotation=90
+                )
+                ax.annotate(
+                    xticklabels, (Xdatas[i_Xdatas[i]], Ydatas[i]), visible=False
+                )
+            else:
+                ax.set_xticklabels(xticklabels, rotation=90)
     elif type_plot == "bargraph":
         positions = range(-ndatas + 1, ndatas, 2)
         if x_max is not None:
@@ -322,7 +331,15 @@ def plot_2D(
             ax.xaxis.set_ticks(xticks)
             plt.xticks(rotation=90, ha="center", va="top")
         if xticklabels is not None:
-            ax.set_xticklabels(xticklabels, rotation=90)
+            if is_indlabels:
+                ax.set_xticklabels(
+                    [i + 1 for i in range(len(xticklabels))], rotation=90
+                )
+                ax.annotate(
+                    xticklabels, (Xdatas[i_Xdatas[i]], Ydatas[i]), visible=False
+                )
+            else:
+                ax.set_xticklabels(xticklabels, rotation=90)
     elif type_plot == "point":
         for i in range(ndatas):
             ax.plot(
@@ -341,7 +358,14 @@ def plot_2D(
             ax.xaxis.set_ticks(xticks)
             plt.xticks(rotation=90, ha="center", va="top")
         if xticklabels is not None:
-            ax.set_xticklabels(xticklabels, rotation=90)
+            if is_indlabels:
+                ax.set_xticklabels(
+                    [i + 1 for i in range(len(xticklabels))], rotation=90
+                )
+                for j, xdata in enumerate(Xdatas[i_Xdatas[i]]):
+                    ax.annotate(xticklabels[j], (xdata, Ydatas[i][j]), visible=False)
+            else:
+                ax.set_xticklabels(xticklabels, rotation=90)
     elif type_plot == "barStackResultant":
         data = Ydatas[0:-1]
 
